require 'spec_helper'

module Hikki
  module Adapters
    describe RedisAdapter, :integration do
      context 'when actually using Redis' do
        subject(:adapter) { RedisAdapter.new }
        let(:data) { { id: id, field1: 'test', field2: 123 } }
        let(:expected) { { 'id' => id, 'field1' => 'test', 'field2' => 123 } }
        let(:id) { '1' }
        let(:collection) { 'collection1' }

        it 'can store and retreive data' do
          adapter.remove_all(collection)
          adapter.index(collection, :field1)
          adapter.save(collection, data)
          expect(adapter.find(collection, id)).to eq expected
          expect(adapter.find(collection, '2')).to eq Hash.new
          expect(adapter.all(collection)).to eq [expected]
          expect(adapter.find_by(collection, :field1, 'test')).to eq [expected]
          expect(adapter.find_by(collection, :field2, 123)).to eq [expected]
          expect(adapter.find_by(collection, :field1, 'foo')).to eq []
          expect(adapter.find_by(collection, :field2, 1)).to eq []
          adapter.remove(collection, id)
          expect(adapter.find(collection, id)).to eq Hash.new
          expect(adapter.all(collection)).to eq []
          10.times do |i|
            adapter.save(collection, { id: i, field1: "test-#{i%2}" })
          end
          expect(adapter.all(collection, {limit: 2, offset: 6})).to eq [{'id' => '6', 'field1' => 'test-0'}, {'id' => '7', 'field1' => 'test-1'}]
          expect(adapter.find_by(collection, :field1, 'test-0', {limit: 2})).to eq [{'id' => '0', 'field1' => 'test-0'}, {'id' => '2', 'field1' => 'test-0'}]
          adapter.remove_all(collection)
          expect(adapter.find(collection, id)).to eq Hash.new
          expect(adapter.all(collection)).to eq []
        end
      end
    end
  end
end